@@ -58,24 +58,26 @@ extern int libconfig_yydebug;
     TOK_INTEGER = 259,             /* TOK_INTEGER  */
     TOK_HEX = 260,                 /* TOK_HEX  */
     TOK_BIN = 261,                 /* TOK_BIN  */
-    TOK_INTEGER64 = 262,           /* TOK_INTEGER64  */
-    TOK_HEX64 = 263,               /* TOK_HEX64  */
-    TOK_BIN64 = 264,               /* TOK_BIN64  */
-    TOK_FLOAT = 265,               /* TOK_FLOAT  */
-    TOK_STRING = 266,              /* TOK_STRING  */
-    TOK_NAME = 267,                /* TOK_NAME  */
-    TOK_EQUALS = 268,              /* TOK_EQUALS  */
-    TOK_NEWLINE = 269,             /* TOK_NEWLINE  */
-    TOK_ARRAY_START = 270,         /* TOK_ARRAY_START  */
-    TOK_ARRAY_END = 271,           /* TOK_ARRAY_END  */
-    TOK_LIST_START = 272,          /* TOK_LIST_START  */
-    TOK_LIST_END = 273,            /* TOK_LIST_END  */
-    TOK_COMMA = 274,               /* TOK_COMMA  */
-    TOK_GROUP_START = 275,         /* TOK_GROUP_START  */
-    TOK_GROUP_END = 276,           /* TOK_GROUP_END  */
-    TOK_SEMICOLON = 277,           /* TOK_SEMICOLON  */
-    TOK_GARBAGE = 278,             /* TOK_GARBAGE  */
-    TOK_ERROR = 279                /* TOK_ERROR  */
+    TOK_OCT = 262,                 /* TOK_OCT  */
+    TOK_INTEGER64 = 263,           /* TOK_INTEGER64  */
+    TOK_HEX64 = 264,               /* TOK_HEX64  */
+    TOK_BIN64 = 265,               /* TOK_BIN64  */
+    TOK_OCT64 = 266,               /* TOK_OCT64  */
+    TOK_FLOAT = 267,               /* TOK_FLOAT  */
+    TOK_STRING = 268,              /* TOK_STRING  */
+    TOK_NAME = 269,                /* TOK_NAME  */
+    TOK_EQUALS = 270,              /* TOK_EQUALS  */
+    TOK_NEWLINE = 271,             /* TOK_NEWLINE  */
+    TOK_ARRAY_START = 272,         /* TOK_ARRAY_START  */
+    TOK_ARRAY_END = 273,           /* TOK_ARRAY_END  */
+    TOK_LIST_START = 274,          /* TOK_LIST_START  */
+    TOK_LIST_END = 275,            /* TOK_LIST_END  */
+    TOK_COMMA = 276,               /* TOK_COMMA  */
+    TOK_GROUP_START = 277,         /* TOK_GROUP_START  */
+    TOK_GROUP_END = 278,           /* TOK_GROUP_END  */
+    TOK_SEMICOLON = 279,           /* TOK_SEMICOLON  */
+    TOK_GARBAGE = 280,             /* TOK_GARBAGE  */
+    TOK_ERROR = 281                /* TOK_ERROR  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
@@ -88,24 +90,26 @@ extern int libconfig_yydebug;
 #define TOK_INTEGER 259
 #define TOK_HEX 260
 #define TOK_BIN 261
-#define TOK_INTEGER64 262
-#define TOK_HEX64 263
-#define TOK_BIN64 264
-#define TOK_FLOAT 265
-#define TOK_STRING 266
-#define TOK_NAME 267
-#define TOK_EQUALS 268
-#define TOK_NEWLINE 269
-#define TOK_ARRAY_START 270
-#define TOK_ARRAY_END 271
-#define TOK_LIST_START 272
-#define TOK_LIST_END 273
-#define TOK_COMMA 274
-#define TOK_GROUP_START 275
-#define TOK_GROUP_END 276
-#define TOK_SEMICOLON 277
-#define TOK_GARBAGE 278
-#define TOK_ERROR 279
+#define TOK_OCT 262
+#define TOK_INTEGER64 263
+#define TOK_HEX64 264
+#define TOK_BIN64 265
+#define TOK_OCT64 266
+#define TOK_FLOAT 267
+#define TOK_STRING 268
+#define TOK_NAME 269
+#define TOK_EQUALS 270
+#define TOK_NEWLINE 271
+#define TOK_ARRAY_START 272
+#define TOK_ARRAY_END 273
+#define TOK_LIST_START 274
+#define TOK_LIST_END 275
+#define TOK_COMMA 276
+#define TOK_GROUP_START 277
+#define TOK_GROUP_END 278
+#define TOK_SEMICOLON 279
+#define TOK_GARBAGE 280
+#define TOK_ERROR 281
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -118,7 +122,7 @@ union YYSTYPE
   double fval;
   char *sval;
 
-#line 122 "grammar.h"
+#line 126 "grammar.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
