@@ -1,6 +1,6 @@
 /* ----------------------------------------------------------------------------
    libconfig - A library for processing structured configuration files
-   Copyright (C) 2005-2018  Mark A Lindner
+   Copyright (C) 2005-2025  Mark A Lindner
 
    This file is part of libconfig.
 
@@ -21,15 +21,27 @@
 */
 
 #include <string.h>
+#include <stdint.h>
 #include <sys/types.h>
 
-#define __new(T) (T *)calloc(1, sizeof(T)) /* zeroed */
+#define BITS_IN_BYTE 8
+
+extern void libconfig_set_fatal_error_func(void (*func)(const char *));
+
+extern void libconfig_fatal_error(const char *message);
+
+extern void *libconfig_malloc(size_t size);
+extern void *libconfig_calloc(size_t nmemb, size_t size);
+extern void *libconfig_realloc(void *ptr, size_t size);
+
+#define __new(T) (T *)libconfig_calloc(1, sizeof(T)) /* zeroed */
 #define __delete(P) free((void *)(P))
 #define __zero(P) memset((void *)(P), 0, sizeof(*P))
 
-extern long long libconfig_parse_integer(const char *s, int *ok);
-extern unsigned long long libconfig_parse_hex64(const char *s);
+extern int libconfig_parse_integer(const char *s, int base, long long *val,
+                                   int *is_long);
 
 extern void libconfig_format_double(double val, int precision, int sci_ok,
                                     char *buf, size_t buflen);
 
+extern char *libconfig_format_bin(int64_t val, char *buf);
